<template>
    <div class="fullheight">
        <div style="display: flex">
            <el-form
                ref="searchForm"
                :model="searchForm"
                label-width="80px"
                class="searchTop"
            >
                <el-input
                    v-model="searchForm.applyAppName"
                    placeholder="请输入项目名称"
                    style="width: 220px; margin-right: 10px; margin-bottom: 5px"
                    clearable
                ></el-input>
                <dict-select
                    dictCode="cloud_type"
                    :hasDefaultOption="true"
                    clearable
                    placeholder="请选择所属云平台"
                    v-model="searchForm.cloudType"
                />
                <el-date-picker
                    v-model="searchForm.startTime"
                    type="date"
                    placeholder="请选择申请开始日期"
                    value-format="yyyy-MM-dd"
                >
                </el-date-picker>
                <el-date-picker
                    v-model="searchForm.endTime"
                    type="date"
                    placeholder="请选择申请结束日期"
                    value-format="yyyy-MM-dd"
                >
                </el-date-picker>
                <el-button size="small" @click="handleSearch" type="primary"
                    >查询</el-button
                >
                <el-button size="small" @click="handleReset" type="plain">重置</el-button>
            </el-form>
        </div>
        <ht-table
            @load="loadData"
            :data="tabelData"
            :pageResult="pageResult"
            :selection="true"
            :show-export="false"
            :show-custom-column="false"
            ref="htTable"
            @row-dblclick="handleEdit"
            :default-sorter="[{direction: 'DESC', property: 'id_'}]"
        >
            <template>
                <ht-table-column
                    prop="applyAppName"
                    width="260"
                    label="应用系统名称"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="cloudType"
                    label="资源所属云平台"
                    width="160"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                    <template slot-scope="{row}">
                        <el-tag v-if="row.cloudType">
                            {{ getDictName('cloud_type', row.cloudType) }}
                        </el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="applyCode"
                    label="申请编号"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <ht-table-column
                    prop="applyUnitName"
                    label="单位名称"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <ht-table-column
                    prop="applyDate"
                    label="申请时间"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                    width="180"
                />
                <ht-table-column
                    prop="status"
                    label="状态"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                    width="100"
                >
                    <template slot-scope="{row}">
                        <el-tag v-if="row.status || row.status === 0">
                            {{ getDictName('cloud_apply_status', row.status) }}
                        </el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column label="操作">
                    <template v-slot="{row}">
                        <el-dropdown
                            size="mini"
                            split-button
                            @command="handleCommand"
                            @click="handleCommand({row, command: 'handleAudit'})"
                        >
                            <span>
                                <i
                                    class="el-icon-connection"
                                    style="margin-right: 5px"
                                ></i>
                                申请执行
                            </span>
                            <el-dropdown-menu slot="dropdown">
                                <el-dropdown-item
                                    icon="el-icon-tickets"
                                    :command="{
                                        row,
                                        command: 'processRecord',
                                    }"
                                    >流程日志</el-dropdown-item
                                >
                            </el-dropdown-menu>
                        </el-dropdown>
                    </template>
                </ht-table-column>
            </template>
        </ht-table>
        <applyForm ref="applyForm" @reload="handleReload" />
        <applyRecord ref="applyRecord" />
    </div>
</template>
<script>
import applyForm from './components/applyForm.vue'
import applyRecord from './components/applyRecord.vue'
import api from './js/api.js'
export default {
    name: 'resourceApply',
    components: {applyForm, applyRecord},
    data() {
        return {
            searchForm: {
                status: 30,
            },
            tabelData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
        }
    },

    methods: {
        handleSearch() {
            this.pageResult.page = 1
            this.loadData()
        },
        handleReset() {
            this.searchForm = {
                status: 10,
            }
            this.pageResult.page = 1
            this.loadData()
        },
        loadData(params, cb) {
            let data = {
                pageBean: this.pageResult,
                querys: this.formatQuery(),
            }
            api.queryApplyApproval(data)
                .then((res) => {
                    this.tabelData = res.rows
                    this.pageResult = {
                        page: res.page,
                        pageSize: res.pageSize,
                        total: res.total,
                    }
                })
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
        formatQuery() {
            let querys = []
            for (let key in this.searchForm) {
                if (this.searchForm[key] !== null) {
                    let operation,
                        property = key

                    switch (key) {
                        case 'applyAppName':
                            operation = 'LIKE'
                            break
                        case 'startTime':
                            operation = 'GREAT_EQUAL'
                            property = 'applyDate'
                            break
                        case 'endTime':
                            operation = 'LESS_EQUAL'
                            property = 'applyDate'
                            break
                        default:
                            operation = 'EQUAL'
                            break
                    }
                    querys.push({
                        group: 'main',
                        operation,
                        parentGroup: '',
                        property,
                        relation: 'AND',
                        value: this.searchForm[key],
                    })
                }
            }
            return querys
        },
        handleEdit(row) {
            this.$nextTick(() => {
                this.$refs.applyForm.handleOpen('excute', 'edit', row)
            })
        },
        handleAdd() {
            this.$nextTick(() => {
                this.$refs.applyForm.handleOpen('excute', 'add')
            })
        },
        handleReload() {
            this.loadData()
        },
        handleCommand(params) {
            if (params.command == 'handleAudit') {
                this.handleEdit(params.row)
            } else if (params.command == 'processRecord') {
                this.$refs.applyRecord.handleOpen(params.row)
            }
        },
    },
}
</script>

<style lang="scss" scoped>
.fullheight {
    padding: 10px;
    position: relative;
}
</style>